<?php

namespace Labrender\FileRepository\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Labrender\FileRepository\Http\Requests\NotificationsRequest;
use Labrender\FileRepository\Interfaces\NotificationsRepositoryInterface;
use Labrender\FileRepository\Models\Notifications;

class NotificationsUserController extends BaseController
{
    /**
     * Initialize notifications controller.
     *
     * @param type NotificationsRepositoryInterface $notifications
     *
     * @return type
     */
    public function __construct(NotificationsRepositoryInterface $notifications)
    {
        $this->repository = $notifications;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Labrender\FileRepository\Repositories\Criteria\NotificationsUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(NotificationsRequest $request)
    {
        $notifications = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('file_repository::notifications.names'));

        return $this->theme->of('file_repository::user.notifications.index', compact('notifications'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Notifications $notifications
     *
     * @return Response
     */
    public function show(NotificationsRequest $request, Notifications $notifications)
    {
        Form::populate($notifications);

        return $this->theme->of('file_repository::user.notifications.show', compact('notifications'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(NotificationsRequest $request)
    {

        $notifications = $this->repository->newInstance([]);
        Form::populate($notifications);

        $this->theme->prependTitle(trans('file_repository::notifications.names'));
        return $this->theme->of('file_repository::user.notifications.create', compact('notifications'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(NotificationsRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $notifications = $this->repository->create($attributes);

            return redirect(trans_url('/user/file_repository/notifications'))
                -> with('message', trans('messages.success.created', ['Module' => trans('file_repository::notifications.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Notifications $notifications
     *
     * @return Response
     */
    public function edit(NotificationsRequest $request, Notifications $notifications)
    {

        Form::populate($notifications);
        $this->theme->prependTitle(trans('file_repository::notifications.names'));

        return $this->theme->of('file_repository::user.notifications.edit', compact('notifications'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Notifications $notifications
     *
     * @return Response
     */
    public function update(NotificationsRequest $request, Notifications $notifications)
    {
        try {
            $this->repository->update($request->all(), $notifications->getRouteKey());

            return redirect(trans_url('/user/file_repository/notifications'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('file_repository::notifications.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(NotificationsRequest $request, Notifications $notifications)
    {
        try {
            $this->repository->delete($notifications->getRouteKey());
            return redirect(trans_url('/user/file_repository/notifications'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('file_repository::notifications.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
